# VT50-2000-2016-84-28-4
# $Copyright: Copyright (c) 2016 Veritas Technologies LLC.
# All rights reserved.
#
# THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION AND TRADE SECRETS OF
# VERITAS TECHNOLOGIES LLC.  USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED
# WITHOUT THE PRIOR EXPRESS WRITTEN PERMISSION OF VERITAS TECHNOLOGIES LLC.
#
# The  Licensed  Software  and  Documentation  are  deemed  to be commercial
# computer  software  as  defined  in  FAR  12.212 and subject to restricted
# rights  as  defined in FAR Section 52.227-19 "Commercial Computer Software
# - Restricted  Rights"  and  DFARS 227.7202,  et seq.  "Commercial Computer
# Software  and  Commercial Computer Software Documentation," as applicable,
# and any successor regulations, whether delivered by Veritas as on premises
# or  hosted  services.  Any  use,  modification,  reproduction  release,
# performance,  display  or  disclosure  of  the  Licensed  Software  and
# Documentation by the U.S. Government shall be solely in accordance with
# the terms of this Agreement. $
#-----------------------------------------------------------------------------
# $Header: /project/isv-agent/ACCLib/lib/vcs/VCSType.pm,v 1.15 2008/10/06 05:09:35 aatre Exp $
#
# Veritas Software Corporation
#
# $Author: aatre $
# $Date: 2008/10/06 05:09:35 $
# $Revision: 1.15 $
#
# Provides: package VCSType
#
# Functionality: VCS Type Related Commands
#
# Authors: 011787
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Methods:
#
#   GetOnlineTimeoutGivenType(<Type>, &<OnlineTimeout>)
#   GetOfflineTimeoutGivenType(<Type>, &<OfflineTimeout>)
#
#-----------------------------------------------------------------------------

#------------------
# version calls
#------------------
use Version;
Version::TellVersion("\$Header: /project/isv-agent/ACCLib/lib/vcs/VCSType.pm,v 1.15 2008/10/06 05:09:35 aatre Exp $::ETVHeader");
#------------------------
# end of version calls
#------------------------

#---------------------------
# Declare the package name.
#---------------------------
package VCSType;

#------------------------------------------
# Turn on strict on vars, refs and subs.
#------------------------------------------
use strict;

#------------------------------------------
# Include all the modules required.
#------------------------------------------
use LogInt;
use Hatype;


=pod

-----------------------------------------------------------------------------
Function: Boolean GetOnlineTimeoutGivenType( IN String ResourceType, 
                                             OUT Integer OnlineMaxWaitPeriod )

Description:
  Gives the online timeout for the given resource type.

Parameters:
  ResourceType        : Type of the resource.
  OnlineMaxWaitPeriod : Number of seconds to wait before the 
                        resource to come online.

Return Value:
  Boolean value in the set of {0,1} where
          0 - false
          1 - true
-----------------------------------------------------------------------------

=cut

sub GetOnlineTimeoutGivenType {

  my ( $sTypeName,
       $riOnlineTimeout ) = @_;

  my $sMyName = (caller 0)[3];

  LogInt::Message( LogInt::LLTrace,
                   10340,
                   "VCSType",
                   "GetOnlineTimeoutGivenType",
                   "Subroutine %s called with: Type [%s]",
                   $sMyName, $sTypeName );

  #-------------------------------------------------------------
  #construct the call to the generic Hatype Display command
  #-------------------------------------------------------------
  my $sTypes      = $sTypeName;
  my $sAttributes = "OnlineTimeout";
  my @lsResults   = ();

  if(Hatype::Display($sTypes, $sAttributes, \@lsResults)) {
    # return ok - continue
  }
  else {
    #-----------------------------------
    # call to get display info failed
    #-----------------------------------
    LogInt::Message( LogInt::LLError,
                     10341,
                     "VCSType",
                     "GetOnlineTimeoutGivenType",
                     "Failed in call to Hatype::Display");

    return 0; #return error
  }

  #---------------------------------
  # format is
  # Application OnlineTimeout 300
  #---------------------------------

  my ( $sTypeTrash,
       $sAttributeTrash,
       $iValue ) = split(/\s/, $lsResults[0]);

  LogInt::Message( LogInt::LLTrace,
                   10342,
                   "VCSType",
                   "GetOnlineTimeoutGivenType",
                   "Called with type [$sTypeName], returning OnlineTimeout [$iValue]");

  $$riOnlineTimeout = $iValue;

  return 1;
}


=pod

-----------------------------------------------------------------------------
Function: Boolean GetOfflineTimeoutGivenType( IN String ResourceType,
                                              OUT Integer OfflineMaxWaitPeriod )

Description:
  Gives the offline timeout for the given resource type.

Parameters:
  ResourceType         : Type of the resource.
  OfflineMaxWaitPeriod : Number of seconds to wait before the
                         resource comes offline.

Return Value:
  Boolean value in the set of {0,1} where
          0 - false
          1 - true
-----------------------------------------------------------------------------

=cut

sub GetOfflineTimeoutGivenType {

  my ( $sTypeName,
       $riOfflineTimeout ) = @_;

  my $sMyName = (caller 0)[3];

  LogInt::Message( LogInt::LLTrace,
                   10343,
                   "VCSType",
                   "GetOfflineTimeoutGivenType",
                   "Subroutine %s called with: Type [%s]",
                   $sMyName, $sTypeName );

  #----------------------------------------------------------------
  # construct the call to the generic Hatype Display command.
  #----------------------------------------------------------------
  my $sTypes      = $sTypeName;
  my $sAttributes = "OfflineTimeout";
  my @lsResults   = ();

  if(Hatype::Display($sTypes, $sAttributes, \@lsResults)) {
    # return ok - continue
  } 
  else {
    #------------------------------------
    # call to get display info failed.
    #------------------------------------
    LogInt::Message( LogInt::LLError,
                     10344,
                     "VCSType",
                     "GetOfflineTimeoutGivenType",
                     "Failed in call to Hatype::Display");

    return 0; #return error
  }

  #------------------------------------
  # format is
  # Application OfflineTimeout 300
  #------------------------------------
  my ( $sTypeTrash, 
       $sAttributeTrash,
       $iValue ) = split(/\s/, $lsResults[0]);

  LogInt::Message( LogInt::LLTrace,
                   10345,
                   "VCSType",
                   "GetOfflineTimeoutGivenType",
                   "Called with type [$sTypeName], returning OfflineTimeout [$iValue]");

  $$riOfflineTimeout = $iValue;

  return 1;
}


1;

